﻿#IMPORTANT NOTE: This script will overwrite any existing Resource Based Delegation settings on the Target Computers. Please run the 
#following command to view any existing delegation settings and append them to the $MWDServer List:
#Get-ADComputer -Identity $Computer -server $domain -Properties PrincipalsAllowedToDelegateToAccount

#The list may use SID's if it is from a trusted domain. If you are given an SID, use the following command to translate the SID from
#the  trusted domain:
#Get-ADComputer –Filter * | Where-Object {$_.SID –like “*1111”} | Select-Object –Property Name, SID
#replace "1111" with the last 4 digits of the SID

# Import the ActiveDirectory module
Import-Module ActiveDirectory

# Create an array and assign it to a variable
#TargetComputers is for the list of File Servers and DFS Shares in the environment.
$TargetComputers = @("FileShare1", "DFSShare1")
$Domain = "domain.tld"

$CurrentDelegation
$MWDServer1 = (Get-ADComputer -Identity MWDServer1)
$MWDServer2 = (Get-ADComputer -Identity MWDServer2)


# Loop through each File/DFS Server configure delegation for the MyWorkDrive Server
ForEach ($Computer in $TargetComputers) {
 
# Add the resource of the current computer to the list of services that FileServer can delegate to
# the "-server domain.tld"'s can be removed if all servers/computers are contained within the same domain; otherwise, specify the domain.
Set-ADComputer -Identity $Computer -server $domain -PrincipalsAllowedToDelegateToAccount $MWDServer1, $MWDServer2
    
# Verify the value of the attribute includes the MyWorkDrive Server. If it is from a trusted domain, it will show as an SID.
Get-ADComputer -Identity $Computer -server $domain -Properties PrincipalsAllowedToDelegateToAccount
}
